@@ -12,24 +12,26 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
-#include "sourcestyle.h"
-#include "sourcestylescheme.h"
+#include "sourcebuffer.h"
+#include "sourcecompletion.h"
+#include "sourcecompletionactivation.h"
+#include "sourcecompletioncontext.h"
+#include "sourcecompletioninfo.h"
+#include "sourcecompletionitem.h"
+#include "sourcecompletionproposal.h"
+#include "sourcecompletionprovider.h"
+#include "sourcecompletionwords.h"
+#include "sourcegutter.h"
+#include "sourceiter.h"
 #include "sourcelanguage.h"
 #include "sourcelanguagemanager.h"
-#include "sourceview.h"
-#include "sourcebuffer.h"
-#include "sourceiter.h"
 #include "sourcemark.h"
-#include "sourcestyleschememanager.h"
-#include "sourcegutter.h"
-#include "sourcecompletioninfo.h"
-#include "sourcecompletionproposal.h"
-#include "sourcecompletionitem.h"
-#include "sourcecompletioncontext.h"
-#include "sourcecompletion.h"
-#include "sourcecompletionprovider.h"
 #include "sourceprintcompositor.h"
-#include "sourcecompletionactivation.h"
+#include "sourcestyle.h"
+#include "sourcestylescheme.h"
+#include "sourcestyleschememanager.h"
+#include "sourceundomanager.h"
+#include "sourceview.h"
 
 extern "C"
 {
@@ -41,6 +43,7 @@ GType gtk_source_completion_get_type(void);
 GType gtk_source_completion_context_get_type(void);
 GType gtk_source_completion_info_get_type(void);
 GType gtk_source_completion_item_get_type(void);
+GType gtk_source_completion_words_get_type(void);
 GType gtk_source_gutter_get_type(void);
 GType gtk_source_language_get_type(void);
 GType gtk_source_language_manager_get_type(void);
@@ -63,6 +66,7 @@ namespace gtksourceview {  class SourceCompletion_Class { public: static Glib::O
 namespace gtksourceview {  class SourceCompletionContext_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace gtksourceview {  class SourceCompletionInfo_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace gtksourceview {  class SourceCompletionItem_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace gtksourceview {  class SourceCompletionWords_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace gtksourceview {  class SourceGutter_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace gtksourceview {  class SourceLanguage_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace gtksourceview {  class SourceLanguageManager_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -85,6 +89,7 @@ void wrap_init()
   Glib::wrap_register(gtk_source_completion_context_get_type(), &gtksourceview::SourceCompletionContext_Class::wrap_new);
   Glib::wrap_register(gtk_source_completion_info_get_type(), &gtksourceview::SourceCompletionInfo_Class::wrap_new);
   Glib::wrap_register(gtk_source_completion_item_get_type(), &gtksourceview::SourceCompletionItem_Class::wrap_new);
+  Glib::wrap_register(gtk_source_completion_words_get_type(), &gtksourceview::SourceCompletionWords_Class::wrap_new);
   Glib::wrap_register(gtk_source_gutter_get_type(), &gtksourceview::SourceGutter_Class::wrap_new);
   Glib::wrap_register(gtk_source_language_get_type(), &gtksourceview::SourceLanguage_Class::wrap_new);
   Glib::wrap_register(gtk_source_language_manager_get_type(), &gtksourceview::SourceLanguageManager_Class::wrap_new);
@@ -100,6 +105,7 @@ void wrap_init()
   gtksourceview::SourceCompletionContext::get_type();
   gtksourceview::SourceCompletionInfo::get_type();
   gtksourceview::SourceCompletionItem::get_type();
+  gtksourceview::SourceCompletionWords::get_type();
   gtksourceview::SourceGutter::get_type();
   gtksourceview::SourceLanguage::get_type();
   gtksourceview::SourceLanguageManager::get_type();
